Index: Dev/twitter/get_oauth.pl
===================================================================
--- Dev/twitter/get_oauth.pl	(revision 8333ea00a9fe608c90c20af12ea0c51548f66f4e)
+++ Dev/twitter/get_oauth.pl	(revision e960958d0632638a955d083bbd912f56ddccdb7e)
@@ -3,5 +3,5 @@
 use warnings;
 use utf8;
-use Net::Twitter::Lite;
+use Net::Twitter::Lite::WithAPIv1_1;
 
 use YAML::Tiny;
@@ -13,5 +13,5 @@
 my $access_token_secret = $config->{'access_token_secret'};
 
-my $nt = Net::Twitter::Lite->new(
+my $nt = Net::Twitter::Lite::WithAPIv1_1->new(
   traits          => ['API::REST', 'OAuth'],
   consumer_key    => $consumer_key,
Index: Dev/twitter/show_status.pl
===================================================================
--- Dev/twitter/show_status.pl	(revision a5b6bf1b18c7adf5e32cc0e020e76b26272902af)
+++ Dev/twitter/show_status.pl	(revision e960958d0632638a955d083bbd912f56ddccdb7e)
@@ -10,8 +10,8 @@
 # You can catch and process these exceptions by using eval blocks and testing $@
 ## from http://search.cpan.org/perldoc?Net::Twitter::Lite#ERROR_HANDLING
-use Net::Twitter::Lite;
+use Net::Twitter::Lite::WithAPIv1_1;
 use Data::Dumper;
 
-my $bot = Net::Twitter::Lite->new(
+my $bot = Net::Twitter::Lite::WithAPIv1_1->new(
     legacy_lists_api => 0,
 );
Index: Dev/twitter/dump_timeline.pl
===================================================================
--- Dev/twitter/dump_timeline.pl	(revision a5b6bf1b18c7adf5e32cc0e020e76b26272902af)
+++ Dev/twitter/dump_timeline.pl	(revision e960958d0632638a955d083bbd912f56ddccdb7e)
@@ -10,5 +10,5 @@
 # You can catch and process these exceptions by using eval blocks and testing $@
 ## from http://search.cpan.org/perldoc?Net::Twitter::Lite#ERROR_HANDLING
-use Net::Twitter::Lite;
+use Net::Twitter::Lite::WithAPIv1_1;
 use FindBin qw($Bin);
 use YAML::Tiny;
@@ -134,11 +134,11 @@
 
 sub login {
     # make Net::Twitter::Lite object and login
     #   param   => hash object of configration
-    #   ret     => Net::Twitter::Lite object
+    #   ret     => Net::Twitter::Lite::WithAPIv1_1 object
     
     my $conf = shift @_;
     
-    my $bot = Net::Twitter::Lite->new(
+    my $bot = Net::Twitter::Lite::WithAPIv1_1->new(
         consumer_key    => $conf->{consumer_key},
         consumer_secret => $conf->{consumer_secret},
@@ -134,11 +134,11 @@
 
 sub login {
-    # make Net::Twitter::Lite object and login
+    # make Net::Twitter::Lite::WithAPIv1_1 object and login
     #   param   => hash object of configration
Index: Dev/twitter/twitterbot.pl
===================================================================
--- Dev/twitter/twitterbot.pl	(revision a5b6bf1b18c7adf5e32cc0e020e76b26272902af)
+++ Dev/twitter/twitterbot.pl	(revision e960958d0632638a955d083bbd912f56ddccdb7e)
@@ -10,5 +10,5 @@
 # You can catch and process these exceptions by using eval blocks and testing $@
 ## from http://search.cpan.org/perldoc?Net::Twitter::Lite#ERROR_HANDLING
-use Net::Twitter::Lite;
+use Net::Twitter::Lite::WithAPIv1_1;
 use FindBin qw($Bin);
 use YAML::Tiny;
@@ -170,11 +170,11 @@
 
 sub login {
     # make Net::Twitter::Lite object and login
     #   param   => hash object of configration
-    #   ret     => Net::Twitter::Lite object
+    #   ret     => Net::Twitter::Lite::WithAPIv1_1 object
     
     my $conf = shift @_;
     
-    my $bot = Net::Twitter::Lite->new(
+    my $bot = Net::Twitter::Lite::WithAPIv1_1->new(
         consumer_key    => $conf->{consumer_key},
         consumer_secret => $conf->{consumer_secret},
@@ -190,5 +190,5 @@
 sub or_search {
     # search tweets containing keywords
-    #   param   => Net::Twitter::Lite object, ArrayRef of keywords, since_id
+    #   param   => Net::Twitter::Lite::WithAPIv1_1 object, ArrayRef of keywords, since_id
     #   ret     => HashRef of status_id (timeline order is destroyed)
     #               or undef (none is found)
@@ -254,5 +254,5 @@
 sub mentions_ids {
     # return status_ids mentioned to me
-    #   param   => Net::Twitter::Lite object, since_id
+    #   param   => Net::Twitter::Lite::WithAPIv1_1 object, since_id
     #   ret     => HashRef of status_id (timeline order is destroyed)
     #               or undef (none is found)
@@ -170,11 +170,11 @@
 
 sub login {
-    # make Net::Twitter::Lite object and login
+    # make Net::Twitter::Lite::WithAPIv1_1 object and login
     #   param   => hash object of configration
Index: Dev/twitter/update_timeline.pl
===================================================================
--- Dev/twitter/update_timeline.pl	(revision a5b6bf1b18c7adf5e32cc0e020e76b26272902af)
+++ Dev/twitter/update_timeline.pl	(revision e960958d0632638a955d083bbd912f56ddccdb7e)
@@ -10,5 +10,5 @@
 # You can catch and process these exceptions by using eval blocks and testing $@
 ## from http://search.cpan.org/perldoc?Net::Twitter::Lite#ERROR_HANDLING
-use Net::Twitter::Lite;
+use Net::Twitter::Lite::WithAPIv1_1;
 use FindBin qw($Bin);
 use YAML::Tiny;
@@ -86,11 +86,11 @@
 
 sub login {
     # make Net::Twitter::Lite object and login
     #   param   => hash object of configration
-    #   ret     => Net::Twitter::Lite object
+    #   ret     => Net::Twitter::Lite::WithAPIv1_1 object
     
     my $conf = shift @_;
     
-    my $bot = Net::Twitter::Lite->new(
+    my $bot = Net::Twitter::Lite::WithAPIv1_1->new(
         consumer_key    => $conf->{consumer_key},
         consumer_secret => $conf->{consumer_secret},
@@ -86,11 +86,11 @@
 
 sub login {
-    # make Net::Twitter::Lite object and login
+    # make Net::Twitter::Lite::WithAPIv1_1 object and login
     #   param   => hash object of configration
